@@ -103,7 +103,7 @@ def refresh():
 			base_mon_hp_start[active_button],
 			base_mon_hp_y_start[active_button]-20,
 			anchor=N, image=g.buttons["sword_pointer.png"], tags="monster_arrow")
-	main.recalc_stats(1)
+	main.recalc_stats()
 
 	#clear and rebuild listbox_item
 	listbox_item.delete(0, END)
@@ -141,7 +141,7 @@ def attack(event=0):
 	global num_dice
 	if used_gem == 1:
 	   player.adj_attack = old_attack
-	   main.attack.set(player.adj_attack)
+	   main.recalc_stats()
 	   num_dice = 1
 	   used_gem = 0
 	attack_player()
@@ -292,7 +292,7 @@ def attack_player_per_monster(i):
 	if damage > 0:
 		main.print_message("The " + monster_list[i].name +
 		" hits you for " + str(damage) + " damage.")
-		player.hp = player.hp - damage
+		player.give_stat("hp", -1*damage)
 		monster_slashed("h")
 		#you dead yet?
 		if player.hp <= 0:
@@ -354,7 +354,7 @@ def monster_dead(i):
 
 	if len(monster_list[i].on_death) == 0:
 		gold = monster_list[i].gold
-		player.gold = str(int(player.gold) + gold)
+		player.give_stat("gold", gold)
 		main.print_message("You find " + str(gold) + " gold,")
 
 		exp = monster_list[i].exp
@@ -436,11 +436,10 @@ def useitem():
 	#if item is healing
 	if item_type == 11:
 		#heal the player, delete the item
-		player.hp=player.hp + g.item.item[item_value].quality
+		player.give_stat("hp", g.item.item[item_value].quality)
 		main.print_message("You are healed for " +
 					str(g.item.item[item_value].quality) + " health.")
 		g.item.drop_inv_item(g.item.find_inv_item(item_value))
-		if player.hp >= player.adj_maxhp: player.hp = player.adj_maxhp
 		attack_player()
 
 	#if item is a gem
@@ -449,13 +448,13 @@ def useitem():
 		old_attack = player.adj_attack
 		gem_power = g.item.item[item_value].quality
 		#gem power increases attack strength potential
-		player.adj_attack = player.adj_attack + gem_power * 0.75
+		player.give_stat("adj_attack", gem_power * 0.75)
 		#gem power increases num_dice (ie. chance to hit and total damage)
 		global num_dice
 		num_dice = num_dice + gem_power/4
 		main.print_message("The " + g.item.item[item_value].name +
 			    " focuses the power of your attack.")
-		main.attack.set(player.adj_attack)
+		main.recalc_stats()
 		g.item.drop_inv_item(g.item.find_inv_item(item_value))
 		global used_gem
 		used_gem=1
@@ -521,19 +520,21 @@ def useskill():
 	if player.skill[skill_index][5] == 0 or player.skill[skill_index][2] > player.ep:
 		return 0
 
-	#pay for the skill
-	player.ep = int(player.ep) - player.skill[skill_index][2]
 
 
 	#actually use the skill.
 	if player.skill[skill_index][1] == 0: #rage
+		#pay for the skill
+		player.give_stat("ep", -1*player.skill[skill_index][2])
 		main.print_message("You fly into a rage.")
 		#increase attack ability
-		player.adj_attack += (1 + int(player.level)/4)
-		main.attack.set(player.adj_attack)
+		player.give_stat("adj_attack", (1 + int(player.level)/4))
+		main.recalc_stats()
 		attack_player()
 
 	elif player.skill[skill_index][1] == 1: #Sneak away
+		#pay for the skill
+		player.give_stat("ep", -1*player.skill[skill_index][2])
 		global run_attempts
 		if g.die_roll(1, 10 + int(player.level) + run_attempts) > 4:
 			main.print_message("You coward! You ran away from the " +
@@ -547,6 +548,8 @@ def useskill():
 			main.print_message("You fail to sneak away.")
 			attack_player()
 	elif player.skill[skill_index][1] == 2: #Frenzy
+		#pay for the skill
+		player.give_stat("ep", -1*player.skill[skill_index][2])
 		mon_num = select_monster()
 		for i in range(3 + int(player.level)/3):
 			if monster_list[mon_num].hp < 1:
@@ -560,12 +563,23 @@ def useskill():
 			refresh()
 		if can_leave() == 0: attack_player()
 	elif player.skill[skill_index][1] == 3: #Dismember
+		#pay for the skill
+		player.give_stat("ep", -1*player.skill[skill_index][2])
 		mon_num = select_monster()
 		if mon_num == -1: return 0
 		damage = (player.adj_attack * 5)/2
 		monster_hurt(mon_num, damage)
 		if can_leave() == 0:
 			attack_player()
+	elif player.skill[skill_index][1] == 4: #Scripted
+		#If the scripting ends with an "end" command,
+		if action.activate_lines(g.xgrid, g.ygrid, g.zgrid,
+								player.skill[skill_index][6]) == 1:
+			#pay for the skill
+			player.give_stat("ep", -1*player.skill[skill_index][2])
+		if can_leave() == 0:
+			attack_player()
+		main.recalc_stats()
 
 	if can_leave() == 1: return 0
 	active_button = -1
@@ -908,6 +922,16 @@ def begin(mon_index_input):
 				monster.monsters[monster.monster_name_to_index(line)]))
 	for i in range(len(monster_list)):
 		monster_list[i].reset()
+		if g.difficulty == 0:
+			monster_list[i].hp -= monster_list[i].hp/5
+			monster_list[i].maxhp -= monster_list[i].maxhp/5
+			monster_list[i].attack -= monster_list[i].attack/5
+			monster_list[i].defense -= monster_list[i].defense/5
+		if g.difficulty == 2:
+			monster_list[i].hp += monster_list[i].hp/5
+			monster_list[i].maxhp += monster_list[i].maxhp/5
+			monster_list[i].attack += monster_list[i].attack/5
+			monster_list[i].defense += monster_list[i].defense/5
 
 	global did_run
 	did_run = 0
