@@ -19,7 +19,7 @@
 #This file contains everything that needs to be accessed by most or all files.
 
 
-#Dragon Hunt 3.47. Released under the GPL. Copyright 2005
+#Dragon Hunt 3.48. Released under the GPL. Copyright 2005
 #(Note to self: when changing version, change variables.txt, README.txt,
 # and setup.py.)
 
@@ -45,26 +45,6 @@ import action
 #This will be displayed on the Title screen and Main screen.
 game_name = ""
 
-# #general character stats
-# name = ""
-# hp = 0
-# ep = 0
-# maxhp = 0
-# maxep = 0
-# attack = 0
-# defense = 0
-# gold = 0
-# exp = 0
-# level = 0
-# skillpoints = 1
-#
-# #stores attack/defense/hp/ep, adjusted by equipment.
-# #kept correct by main.refreshmap(). Use these for calculations.
-# adj_attack = 0
-# adj_defense = 0
-# adj_maxhp = 0
-# adj_maxep = 0
-
 #fill colour
 fill_colour = "#b9e5ad"
 fill_sel_colour = "#7aa96e"
@@ -92,9 +72,6 @@ var_list = {}
 #of bombs from inv. UNUSED
 cur_mon_hp = 0
 
-# #Name of current hero picture.
-# cur_hero = "people/hero_w.png"
-
 #Current window in use (main, battle, inventory)
 cur_window = "main"
 
@@ -111,10 +88,6 @@ mod_directory = ""
 #per turn scripting, for hp recovery and the like.
 per_turn_script = []
 
-#Has tk been inited yet? Used between rpg.py and new_game.py to decide where
-#to init tk.
-init_tk_already = 0
-
 #Default key bindings for the game.
 binding_up="<Up>"
 binding_down="<Down>"
@@ -128,7 +101,12 @@ binding_quit="q"
 binding_inv="i"
 binding_inv_right="<Next>"
 binding_inv_left="<Prior>"
+binding_console="~"
 message_lines = 6
+difficulty = 1
+
+#Used in new_game
+default_player_name = "Alfred"
 
 #save the game in saves/input.
 #uses pickle, first line is a version number.
@@ -269,6 +247,7 @@ def init_data():
 	read_maps()
 	read_scripts()
 	item.read_items()
+	read_skills()
 	monster.read_monster()
 	global game_name
 	game_name = read_game_name()
@@ -309,8 +288,9 @@ def read_settings():
 	global binding_inv
 	global binding_inv_right
 	global binding_inv_left
+	global binding_console
 	global message_lines
-
+	global difficulty
 	#try to open settings.txt. If it doesn't exist,
 	# just use the default settings.
 	try: file = open("../settings.txt", 'r')
@@ -345,8 +325,12 @@ def read_settings():
 			binding_inv_right = line.split("=", 1)[1].strip()
 		if (line.split("=", 1)[0].strip() == "inv_left"):
 			binding_inv_left = line.split("=", 1)[1].strip()
+		if (line.split("=", 1)[0].strip() == "load_console"):
+			binding_console = line.split("=", 1)[1].strip()
 		if (line.split("=", 1)[0].strip() == "message_lines"):
 			message_lines = line.split("=", 1)[1].strip()
+		if (line.split("=", 1)[0].strip() == "difficulty"):
+			difficulty = int(line.split("=", 1)[1].strip())
 		line = file.readline()
 
 
@@ -373,6 +357,9 @@ def read_variables():
 		elif (line.split("=", 1)[0].strip() == "tilesize"):
 			global tilesize
 			tilesize = int(line.split("=", 1)[1].strip())
+		elif (line.split("=", 1)[0].strip() == "default_player_name"):
+			global default_player_name
+			default_player_name = line.split("=", 1)[1].strip()
 		line = file.readline()
 
 #given a dice set and string of the form 2d4+5, place in new_game_dice
@@ -412,24 +399,25 @@ def read_perturn():
 				per_turn_script[turn_num].append(line)
 
 
-# #skills array. Each skill is a separate line in the array. Each line goes:
-# #name, effect, level, price, description, acquired
-# #effect is an integer that tells battle.py which case in a select to pick.
-# #level is the skillpoints required to get the skill,
-# #price is the ep needed to use.
-# #acquired tells if the skill has already been learned by the player.
-# skill = []
+#skills array. Each skill is a separate line in the array. Each line goes:
+#name, effect, level, price, description, acquired, scripting.
+#effect is an integer that tells battle.py which case in a select to pick.
+#(0=Rage, 1=Sneak, 2=Frenzy, 3=Dismember, 4=Scripted.)
+#level is the skillpoints required to get the skill,
+#price is the ep needed to use.
+#acquired tells if the skill has already been learned by the player.
 
 #Add a skill to the skill[] array
-def addskill(name, effect, level, price, description):
+def addskill(name, effect, level, price, description, scripting=[]):
 	player.skill.append([])
 	i = len(player.skill)
 	player.skill[i-1].append(name)
-	player.skill[i-1].append(effect)
-	player.skill[i-1].append(level)
-	player.skill[i-1].append(price)
+	player.skill[i-1].append(int(effect))
+	player.skill[i-1].append(int(level))
+	player.skill[i-1].append(int(price))
 	player.skill[i-1].append(description)
 	player.skill[i-1].append(0)
+	player.skill[i-1].append(scripting)
 
 
 #takes a skill name, and returns its location in the
@@ -448,7 +436,7 @@ def add_skill(skill_loc):
 		player.skill[skill_loc][5] = 1
 		return 1
 
-#add skills. I really should change these to scripts sometime.
+#Add built-in skills.
 addskill("Rage",       0, 1, 10,
 	"Gives you increased damage for the rest of a battle")
 addskill("Sneak Away", 1, 1, 10,
@@ -458,6 +446,53 @@ addskill("Dismember",  3, 2, 20,
 addskill("Frenzy",  2, 2, 30,
 	"Your next attack will try to hit more than once")
 
+#Load the skills. Requires g.mod_directory to be set
+def read_skills():
+	if path.exists(g.mod_directory + "/data/skills.txt"):
+		temp_skills = read_script_file("/data/skills.txt")
+	#temp storage for the skill data
+	temp_skill_name = ""
+	temp_skill_level = 0
+	temp_skill_price = 0
+	temp_skill_description = ""
+	temp_skill_scripting = []
+	#Are we entering skill data (0) or scripting (1)?
+	data_or_scripting = 0
+
+	for line in temp_skills:
+		line_strip = line.strip()
+		if line_strip[0] == ":":
+			#switch between data or scripting
+			if line_strip[1:].lower() == "scripting":
+				data_or_scripting = 1
+			elif line_strip[1:].lower() == "data":
+				data_or_scripting = 0
+			else: #Or just input a new skill.
+				#If we have any data, add the previous skill
+				if temp_skill_name != "":
+					addskill(temp_skill_name, 4, temp_skill_level,
+							temp_skill_price,
+							temp_skill_description, temp_skill_scripting)
+
+				temp_skill_name = line_strip[1:]
+				temp_skill_level = 0
+				temp_skill_price = 0
+				temp_skill_description = ""
+				temp_skill_scripting = []
+		else:
+			if data_or_scripting == 0:
+				command = line_strip.split("=", 1)[0].lower().strip()
+				value = line_strip.split("=", 1)[1].strip()
+				if command == "level": temp_skill_level = value
+				elif command == "price": temp_skill_price = value
+				elif command == "description": temp_skill_description = value
+			else:
+				temp_skill_scripting.append(line_strip)
+	if temp_skill_name != "":
+		addskill(temp_skill_name, 4, temp_skill_level,
+				temp_skill_price,
+				temp_skill_description, temp_skill_scripting)
+
 
 #Rolls dice in the form 2d6, where 2 is the number of dice, and 6 the number of
 #sides on each die. modify is the bonus given to each die. Use die_roll(2, 6)
@@ -492,7 +527,16 @@ def checklocation(x, y):
 		return 'a'
 
 #like checklocation, but just returns 0 (unwalkable) or 1 (walkable)
-def iswalkable(x, y):
+def iswalkable(x, y, dx, dy):
+        #set direction hero is moving in
+        if dy == -1:
+            move_direction = "n"
+        elif dy == 1:
+            move_direction = "s"
+        elif dx == -1:
+            move_direction = "w"
+        else:
+            move_direction = "e"
 
 	#Assume that all off-map areas (to north or west) are unwalkable.
 	if x < 0 or y < 0:
@@ -501,6 +545,26 @@ def iswalkable(x, y):
 		#this will fail when looking too far right or down
 		if maps[zgrid].field[y][x].walk == 0:
 			return 0
+                #can't move onto tile if there's a wall in the way
+                if maps[zgrid].field[y][x].walk == 1:
+                    if maps[zgrid].field[y][x].wall_s == 1 and move_direction == "n":
+                        return 0
+                    elif maps[zgrid].field[y][x].wall_n == 1 and move_direction == "s":
+                        return 0
+                    elif maps[zgrid].field[y][x].wall_e == 1 and move_direction == "w":
+                        return 0
+                    elif maps[zgrid].field[y][x].wall_w == 1 and move_direction == "e":
+                        return 0
+                #can't move out of old tile if there's a wall in the way
+                if maps[zgrid].field[y-dy][x-dx].wall_s == 1 and move_direction == "s":
+                    return 0
+                elif maps[zgrid].field[y-dy][x-dx].wall_n == 1 and move_direction == "n":
+                    return 0
+                elif maps[zgrid].field[y-dy][x-dx].wall_e == 1 and move_direction == "e":
+                    return 0
+                elif maps[zgrid].field[y-dy][x-dx].wall_w == 1 and move_direction == "w":
+                    return 0
+
 	except IndexError:
 		return 0
 	#By this point, it is known to be walkable.
@@ -546,7 +610,7 @@ def load_buttons():
 		buttons[image_name] = image
 
 
-#given a filename, return the script contained in the file. dont_interpret will
+#given a filename, return the script contained in the file. from_editor will
 #be used for the map editor, to keep it from shredding formatting.
 def read_script_file(file_name, from_editor=0):
 	temp_array = []
@@ -581,6 +645,19 @@ def interpret_lines(temp_array):
 #of all images in that directory, and all subdirectories.
 def read_images(dir_name):
 	image_dictionary =  {"blank" : ImageTk.PhotoImage("RGB", (32, 32))}
+	for root, dirs, files in walk("../modules/default/" + dir_name):
+		(head, tail) = path.split(root)
+		if (tail != "CVS"):
+			for tilename in files:
+				#if image is in a sub-dir:
+				if (root != "../modules/default/" + dir_name):
+					i = len("../modules/default/" + dir_name)
+					image_dictionary[root[i:] + "/" + tilename] = \
+						ImageTk.PhotoImage(file=root + "/" + tilename)
+				else: #if image is in root dir
+					image_dictionary[tilename] = \
+						ImageTk.PhotoImage(file=root + "/" + tilename)
+
 	for root, dirs, files in walk(g.mod_directory + dir_name):
 		(head, tail) = path.split(root)
 		if (tail != "CVS"):
