@@ -105,6 +105,7 @@ def rm_equip():
 			main.print_message("You take off your " +
 				item.item[player.equip[sel_equipment]].name)
 			player.equip[sel_equipment] = -1
+	player.reset_stats()
 	refresh_inv()
 
 #takes an item from the inventory, and wears it.
@@ -128,6 +129,7 @@ def wear_item():
 		item.take_inv_item(temp)
 		main.print_message("You equip yourself with your " +
 			item.item[player.equip[item_loc]].name + ".")
+		player.reset_stats()
 		refresh_inv()
 
 #drops an item from the inventory. Uses curr_item
@@ -256,9 +258,8 @@ def use_item():
 	#if item is healing
 	if item_loc == 11:
 		#heal the player, delete the item
-		player.hp=player.hp + item.item[item_value].quality
+		player.give_stat("hp", item.item[item_value].quality)
 		item.drop_inv_item(curr_item)
-		if player.hp >= player.adj_maxhp: player.hp = player.adj_maxhp
 	if item_loc == 16 or item_loc == 17:
 		if action.activate_lines(g.xgrid, g.ygrid, g.zgrid,
 										item.item[item_value].scripting) == 1:
