@@ -78,8 +78,6 @@ exp = StringVar()
 level = StringVar()
 
 
-
-
 #Print a message in status box. Works with ~Action~ embedded commands.
 def print_message(message):
 	try:
@@ -105,7 +103,7 @@ def save_game(event=0):
 def dead_yet():
 	#did you die?
 	if player.hp <= 0:
-		action.activate_line(g.xgrid, g.ygrid, g.zgrid, "die")
+		action.run_command(g.xgrid, g.ygrid, g.zgrid, "die()")
 		return 1
 	return 0
 
@@ -139,10 +137,15 @@ def activate_scripting(x, y, z):
 	return_num = 0
 	temp_zgrid = z
 
+	#Make sure this is a "real" tile:
+	if(z < 0 or x < 0 or y < 0 or z >= len(g.maps) or
+	y >= len(g.maps[g.zgrid].field) or x >= len(g.maps[g.zgrid].field[y])):
+		return
+
 	itemnum = 0
 	while itemnum < len(g.maps[g.zgrid].field[y][x].items):
 		itemname = g.maps[g.zgrid].field[y][x].items[itemnum]
-		if action.activate_line(x, y, z, "find \"" + itemname + "\" a"):
+		if action.run_command(x, y, z, "find (\"" + itemname + "\", \"a\")"):
 			g.maps[g.zgrid].del_item(itemname, x, y)
 			refresh_tile(x, y)
 		else: itemnum += 1
@@ -190,48 +193,15 @@ def process_onload():
 							g.maps[g.zgrid].field[y][x].onload)
 			if dead_yet() == 1: break
 
-#recalculate and display stats. leave_att_def_alone is for calling from a
-#battle, with the possibility of temp bonuses to attack/defense.
-def recalc_stats(leave_att_def_alone = 0):
+#re-display stats.
+def recalc_stats():
 	name.set(player.name)
-	if leave_att_def_alone == 0:
-		#adjust attack and defense based on equipment.
-		player.adj_attack = int(player.attack)
-		if player.equip[0] != -1:
-			player.adj_attack = player.adj_attack + g.item.item[player.equip[0]].quality
-		for i in range(6):
-			if player.equip[i] != -1:
-				player.adj_attack = player.adj_attack + \
-							g.item.item[player.equip[i]].attack_bonus
-		attack.set(player.adj_attack)
-
-		player.adj_defense = int(player.defense)
-		for i in range(1, 6):
-			if player.equip[i] != -1:
-				player.adj_defense = player.adj_defense + \
-							g.item.item[player.equip[i]].quality
-		for i in range(6):
-			if player.equip[i] != -1:
-				player.adj_defense = player.adj_defense + \
-							g.item.item[player.equip[i]].defense_bonus
-		defense.set(player.adj_defense)
-
+	attack.set(player.adj_attack)
+	defense.set(player.adj_defense)
 	gold.set(player.gold)
 	exp.set(player.exp)
 	level.set(player.level)
 
-	player.adj_maxhp = int(player.maxhp)
-	for i in range(6):
-		if player.equip[i] != -1:
-			player.adj_maxhp = player.adj_maxhp + g.item.item[player.equip[i]].hp_bonus
-	if player.hp > player.adj_maxhp: player.hp = player.adj_maxhp
-
-	player.adj_maxep = int(player.maxep)
-	for i in range(6):
-		if player.equip[i] != -1:
-			player.adj_maxep = player.adj_maxep + g.item.item[player.equip[i]].ep_bonus
-	if player.ep > player.adj_maxep: player.ep = player.adj_maxep
-
 	#hp/ep bars
 	canvas_hp.delete("show_hp")
 	temp_width = g.hpbar_width*player.hp/player.adj_maxhp
@@ -285,6 +255,7 @@ def move_hero(x, y):
 	try:
 		tempy = g.ygrid + y
 		tempx = g.xgrid + x
+
 		#check for either the main window not existing, or a current dialog
 		if window_main.state() != "normal" or action.has_dialog == 1:
 			return
@@ -293,7 +264,7 @@ def move_hero(x, y):
 		#the scripting changes the walkable status.
 		activate_scripting(tempx, tempy, g.zgrid)
 
-		if g.iswalkable(tempx, tempy):
+		if g.iswalkable(tempx, tempy, x, y):
 			if g.allow_move == 1:
 				g.xgrid=g.xgrid + x
 				g.ygrid=g.ygrid + y
@@ -397,7 +368,7 @@ def start_battle(mon_index):
 	g.cur_window = "main"
 	button_inv.config(state=NORMAL)
 	button_save.config(state=NORMAL)
-#	create_map()
+	player.reset_stats()
 	refreshmap()
 	bind_keys()
 	return return_num
@@ -522,10 +493,51 @@ def activate_yesno(event=None):
 	global return_from_yesno
 	return_from_yesno.set("1")
 
+#Display the scripting console. This window will take scripting, then
+#execute it.
+def load_console(event=None):
+	#Only let cheaters access the console.
+	if player.name != "testing123" and player.name != "god" and \
+									player.name != "script_test":
+		return 0
+	global console_text
+	console_text = Text(right, width=80, height=12)
+	console_text.grid(row=0, column=0, columnspan=2)
+	global accept_button
+	accept_button = Button(right, text="run scripting", command=accept_console)
+	accept_button.grid(row=0, column=0, sticky=S)
+	window_main.unbind(g.binding_up)
+	window_main.unbind(g.binding_right)
+	window_main.unbind(g.binding_left)
+	window_main.unbind(g.binding_down)
+	window_main.unbind(g.binding_cancel)
+	window_main.unbind(g.binding_inv)
+	window_main.unbind(g.binding_attack)
+	window_main.unbind(g.binding_save)
+	window_main.unbind(g.binding_quit)
+	window_main.unbind(g.binding_action)
+	window_main.unbind(g.binding_console)
+
+#Called on hitting the "run scripting" button in the console. Runs the scripting
+#in the console, then destroys the console.
+def accept_console(event=None):
+	global console_text
+	global accept_button
+	console_input = console_text.get(1.0, END)
+	console_array = console_input.split("\n")
+
+	console_text.destroy()
+	accept_button.destroy()
+	bind_keys()
+	action.activate_lines(g.xgrid, g.ygrid, g.zgrid, g.interpret_lines(console_array))
+
+
+#If the main window is destroyed unexpectedly, try to prevent the worst errors.
 def cleanup(event=None):
 	activate_yesno()
 	battle.return_from_dialog.set("2")
 	window_main.destroy()
+	action.has_dialog = 0
 
 #call to create window_main.
 def init_window_main(new_game = 0):
@@ -641,6 +653,7 @@ def init_window_main(new_game = 0):
 	#put in the map, and do finishing touches on the window.
 	process_onload()
 	player.cur_hero = "people/hero_w" + g.maps[g.zgrid].hero_suffix + ".png"
+	player.reset_stats()
 	refreshmap()
 	window_main.wm_geometry("+%d+%d" % (10, 10))
 	window_main.focus()
@@ -654,14 +667,15 @@ def init_window_main(new_game = 0):
 	bind_keys()
 	window_main.protocol("WM_DELETE_WINDOW", cleanup)
 
+	#action.has_dialog = 0
 	#call newgame script
 	if new_game == 1:
 		action.activate_lines(g.xgrid, g.ygrid, g.zgrid, g.newgame_act)
 	g.allow_move = 1
-	action.has_dialog = 0
 
 	#keep the new_game window asleep until this one is closed.
 	window_main.master.wait_window(window_main)
+	return 0
 
 #needed for some bindings.
 def do_nothing(event=0):
@@ -680,6 +694,7 @@ def bind_keys():
 	window_main.bind(g.binding_save, save_game)
 	window_main.bind(g.binding_quit, close_window)
 	window_main.bind(g.binding_action, show_inv)
+	window_main.bind(g.binding_console, load_console)
 
 #handles mouse clicks on the main tile canvas.
 def mouse_handler(event=0):
