@@ -35,6 +35,11 @@ class tile:
 		self.name = symbol
 		#Can the tile be walked on?
 		self.walk = 0
+                #walls
+                self.wall_n = 0
+                self.wall_s = 0
+                self.wall_e = 0
+                self.wall_w = 0
 		#An array of lines, describing the scripting run on load.
 		self.onload = []
 		#An array of lines, describing the scripting run when stepped on.
@@ -96,6 +101,7 @@ class map:
 		#0 for onload, 1 for action.
 		tilemode=0
 		for map_line in map_file:
+			if map_line == "\n": continue
 			map_strip = map_line.strip()
 			#go through all lines of the file up to ":def"
 			if curr_mode == 0:
@@ -113,7 +119,7 @@ class map:
 				else:
 					map_command = map_line.split("=", 2)[0].strip().lower()
 					if map_command == "monster":
-						self.monster.append(map_line.split("=", 1)[1])
+						self.monster.append(map_line.split("=", 1)[1].strip())
 					elif map_command == "battle_bg":
 						self.battle_background = \
 							g.backgrounds[map_line.split("=", 1)[1].strip()]
@@ -211,6 +217,7 @@ class map:
 		if self.battle_background == "":
 			self.battle_background = g.backgrounds["generic.png"]
 
+
 	def add_tile(self, tile_name):
 		new_tile = tile(tile_name)
 		self.tiles[tile_name] = new_tile
