@@ -66,6 +66,9 @@ item_desc  = StringVar()
 curr_gold  = StringVar()
 curr_skill = StringVar()
 
+global store_name
+store_name = StringVar()
+
 #refresh the button canvas
 def refresh_buttons(event=0):
 	canvas_buttons.delete(ALL)
@@ -208,9 +211,9 @@ def sell_item():
 	if (item.item[item.inv[curr_item]].type == 14 and
 		        g.shops[store_num].name == "a Gem Shop"):
 		main.print_message("The Gem Shop owner is happy to pay the true value of your gems.")
-		player.gold = int(player.gold) + item.item[item.inv[curr_item]].price
+		player.give_stat("gold", item.item[item.inv[curr_item]].price)
 	else:
-	   	player.gold = int(player.gold) + item.item[item.inv[curr_item]].value
+		player.give_stat("gold", item.item[item.inv[curr_item]].value)
 
 	main.print_message("You sell your " + item.item[item.inv[curr_item]].name
 		+ ".")
@@ -233,21 +236,21 @@ def buy_item():
 			#if no actions were given
 			if (len(g.shops[store_num].itemlist[curr_item].actions) == 0):
 				#if given successfully.
-				if (main.action.activate_line(0, 0, 0, "item " +
-						g.shops[store_num].itemlist[curr_item].item_name)
+				if (main.action.run_command(0, 0, 0, "item(\"" +
+						g.shops[store_num].itemlist[curr_item].item_name+"\")")
 						== 1):
 					main.print_message("You buy a " +
 					g.shops[store_num].itemlist[curr_item].item_name + ".")
-					player.gold = int(player.gold) - \
-					int(g.shops[store_num].itemlist[curr_item].cost)
+					player.give_stat("gold", -1*
+						int(g.shops[store_num].itemlist[curr_item].cost))
 				else: #not enough room
 					main.print_message("Your inventory is full.")
 			else:
 				temp = main.action.activate_lines(0, 0, 0,
 						g.shops[store_num].itemlist[curr_item].actions)
 				if temp == 1:
-					player.gold = int(player.gold) - \
-							int(g.shops[store_num].itemlist[curr_item].cost)
+					player.give_stat("gold", -1*
+							int(g.shops[store_num].itemlist[curr_item].cost))
 	else: #skillpoints
 		#if enough skillpoints
 		if int(g.shops[store_num].itemlist[curr_item].cost) <= \
@@ -255,19 +258,19 @@ def buy_item():
 			#if no actions were given
 			if (len(g.shops[store_num].itemlist[curr_item].actions) == 0):
 				#if given successfully.
-				if (main.action.activate_line(0, 0, 0, "item " +
-						g.shops[store_num].itemlist[curr_item].item_name)
+				if (main.action.run_command(0, 0, 0, "item(\"" +
+						g.shops[store_num].itemlist[curr_item].item_name+"\")")
 						== 1):
 					main.print_message("You buy a " +
 					g.shops[store_num].itemlist[curr_item].item_name + ".")
-					player.skillpoints = int(player.skillpoints) - \
-					int(g.shops[store_num].itemlist[curr_item].cost)
+					player.give_stat("skillpoints", -1*
+					int(g.shops[store_num].itemlist[curr_item].cost))
 			else:
 				temp = main.action.activate_lines(0, 0, 0,
 							g.shops[store_num].itemlist[curr_item].actions)
 				if temp == 1:
-					player.skillpoints = int(player.skillpoints) - \
-							int(g.shops[store_num].itemlist[curr_item].cost)
+					player.give_stat("skillpoints", -1*
+							int(g.shops[store_num].itemlist[curr_item].cost))
 
 	refresh_inv()
 	refresh_shop()
@@ -410,9 +413,10 @@ def init_window_shop(store_type_input):
 	global cur_button
 	cur_button = 2
 
+	store_type_input=store_type_input.lower()
 	global store_num
 	for i in range(len(g.shops)):
-		if (g.shops[i].name == store_type_input):
+		if (g.shops[i].name.lower() == store_type_input):
 			store_num = i
 			break
 
@@ -422,7 +426,7 @@ def init_window_shop(store_type_input):
 	global canvas_inv
 	canvas_inv = Canvas(window_shop, width=temp_canvas_width,
 		height=temp_canvas_height, highlightthickness=0, bg=g.outline_colour)
-	canvas_inv.grid(column=1, row=3, columnspan=2, rowspan=16)
+	canvas_inv.grid(column=1, row=2, columnspan=2, rowspan=16)
 	#outside border
 	canvas_inv.create_rectangle(0,0, temp_canvas_width-1, temp_canvas_height-1)
 	#per-item borders
@@ -437,7 +441,7 @@ def init_window_shop(store_type_input):
 	global canvas_shop
 	canvas_shop = Canvas(window_shop, width=temp_canvas_width,
 		height=temp_canvas_height, highlightthickness=0, bg=g.outline_colour)
-	canvas_shop.grid(column=6, row=3, columnspan=2, rowspan=16)
+	canvas_shop.grid(column=6, row=2, columnspan=2, rowspan=16)
 	#outside border
 	canvas_shop.create_rectangle(0,0, temp_canvas_width-1, temp_canvas_height-1)
 	#per-item borders
@@ -449,8 +453,14 @@ def init_window_shop(store_type_input):
 										(y+1)*(g.tilesize + 2), fill=g.fill_colour)
 
 	#Info labels
+        global store_name
+        store_name.set(g.shops[store_num].name)
+        label_inv = Label(window_shop, text="Inventory",
+                bg=bgcolour).grid(row=1, column=2, sticky=W)
+        label_shop = Label(window_shop, textvar=store_name,
+                bg=bgcolour).grid(row=1, column=6, sticky=E)
 	label_name = Label(window_shop, textvar=item_name,
-		wraplength=143, bg=bgcolour).grid(row=8, column=3, sticky=W)
+		wraplength=143, bg=bgcolour).grid(row=8, column=3, sticky=NW)
 	global label_cost
 	label_cost = Label(window_shop,
 		textvar=item_cost, bg=bgcolour)
